@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Getopt::Long::Descriptive 0.115;
+package Getopt::Long::Descriptive 0.116;
 # ABSTRACT: Getopt::Long, but simpler and more powerful
 
 use v5.12;
@@ -474,12 +474,14 @@ sub _build_describe_options {
       show_defaults => $arg->{show_defaults},
     });
 
-    Getopt::Long::Configure(@go_conf);
+    my $old_go_conf = Getopt::Long::Configure(@go_conf);
 
     my %return;
     $usage->die unless GetOptions(\%return, grep { length } @getopt_specs);
     my @given_keys = keys %return;
 
+    Getopt::Long::Configure($old_go_conf);
+
     for my $opt (keys %return) {
       my $newopt = _munge($opt);
       next if $newopt eq $opt;
@@ -734,7 +736,7 @@ Getopt::Long::Descriptive - Getopt::Long, but simpler and more powerful
 
 =head1 VERSION
 
-version 0.115
+version 0.116
 
 =head1 SYNOPSIS
 
@@ -1052,10 +1054,6 @@ Diab Jerius <djerius@cfa.harvard.edu>
 
 =item *
 
-Hans Dieter Pearcey <hdp@pobox.com>
-
-=item *
-
 Hans Dieter Pearcey <hdp@weftsoar.net>
 
 =item *
